@@ -49,18 +49,17 @@ gconf_search_dialog_class_init (GConfSearchDialogClass *klass)
 
 
 static void
-gconf_search_not_found_dialog (GConfEditorWindow *window) 
+gconf_search_not_found_dialog (GConfSearchDialog *dialog) 
 {
 	GtkWidget *not_found_dialog;
 	
-	not_found_dialog = gtk_message_dialog_new (GTK_WINDOW (window),
+	not_found_dialog = gtk_message_dialog_new (GTK_WINDOW (dialog),
 						   GTK_DIALOG_DESTROY_WITH_PARENT,
 						   GTK_MESSAGE_ERROR,
 						   GTK_BUTTONS_CLOSE,
 						   _("Pattern not found"));
 	gtk_dialog_run (GTK_DIALOG (not_found_dialog));
 	gtk_widget_destroy (GTK_WIDGET (not_found_dialog));
-	
 }
 
 static void
@@ -117,7 +116,7 @@ gconf_search_dialog_search (GtkWidget *button, GConfSearchDialog *dialog)
 		if (res != 0) {
 			gtk_widget_destroy (GTK_WIDGET (dialog));
 		} else {
-			gconf_search_not_found_dialog(window);
+			gconf_search_not_found_dialog (dialog);
 		}
 	}
 }
@@ -138,8 +137,6 @@ gconf_search_dialog_init (GConfSearchDialog *dialog)
 	vbox = gtk_vbox_new (FALSE, 6);
 	gtk_container_set_border_width (GTK_CONTAINER (vbox), 5);
 
-	gtk_window_set_destroy_with_parent (GTK_WINDOW (dialog), TRUE);
-
 	gtk_dialog_add_button (GTK_DIALOG (dialog), GTK_STOCK_CLOSE, GTK_RESPONSE_CLOSE);
 
 	gtk_window_set_title (GTK_WINDOW (dialog), _("Find"));
